@@ -6,6 +6,7 @@ autoconf=autoconf
 libtoolize=libtoolize
 autoheader=autoheader
 
+test -d autom4te.cache && rm -r autom4te.cache
 test -d config || mkdir config
 if [ -d .git ]; then
     git submodule init
@@ -54,7 +55,7 @@ sh_flags=""
 conf_flags=""
 case $1 in
     -d)
-	sh_cflags="-g -Wall -Wdeclaration-after-statement -Wstrict-prototypes"
+	sh_cflags="-O0 -g -Wall -Wdeclaration-after-statement -Wstrict-prototypes"
 	sh_cxxflags="-g -Wall"
 	enable_configure=true
 	enable_help=false
