@@ -66,7 +66,13 @@ const char *myrec[] = {
         "1234567890" "1234567890""1234567890""1234567890""1234567890"
         "1234567890" "1234567890""1234567890""1234567890""1234567890"
         "1234567890" "1234567890""1234567890""1234567890""1234567890"
-        "12345"
+        "1234567890" "1234567890""1234567890""1234567890""1234567890"
+        "1234567890" "1234567890""1234567890""1234567890""1234567890"
+        "1234567890" "1234567890""1234567890""1234567890""1234567890"
+        "1234567890" "1234567890""1234567890""1234567890""1234567890"
+        "1234567890" "1234567890""1234567890""1234567890""1234567890"
+        "1234567890" "1"
+
         "</title>"
         "</gils>"
         ,
@@ -184,7 +190,14 @@ static void tst(int argc, char **argv)
                  "1234567890" "1234567890""1234567890""1234567890""1234567890"
                  "1234567890" "1234567890""1234567890""1234567890""1234567890"
                  "1234567890" "1234567890""1234567890""1234567890""1234567890"
-                 "12345"
+
+
+                 "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                 "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                 "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                 "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                 "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                 "1234567890" "1"
                  , 1));
     
     YAZ_CHECK(
@@ -195,7 +208,13 @@ static void tst(int argc, char **argv)
                    "1234567890" "1234567890""1234567890""1234567890""1234567890"
                    "1234567890" "1234567890""1234567890""1234567890""1234567890"
                    "1234567890" "1234567890""1234567890""1234567890""1234567890"
-                   "123456"
+    
+                   "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                   "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                   "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                   "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                   "1234567890" "1234567890""1234567890""1234567890""1234567890"
+                   "1234567890" "12"
                    , 0, 11));
     
 
